import { useState, useEffect, useMemo, useCallback } from 'react';
import { AgGridReact } from 'ag-grid-react';
import { api, useStaff } from "@nice/client";
import { Button, CascaderProps, message, Modal } from 'antd';
import { areaOptions } from '@web/src/app/main/staffinfo_write/area-options';
import StaffInfoWrite from '@web/src/app/main/staffinfo_write/staffinfo_write.page';

function getAreaName(codes: string[], level?: number): string {
    const result: string[] = [];
    let currentLevel: CascaderProps['options'] = areaOptions;
    for (const code of codes) {
        const found = currentLevel?.find(opt => opt.value === code);
        if (!found) break;
        result.push(String(found.label));
        currentLevel = found.children || [];
        if (level && result.length >= level) break; // 添加层级控制
    }
    return level ? result[level - 1] || '' : result.join(' / ') || codes.join('/');
}

export default function StaffMessage() {
    const [rowData, setRowData] = useState<any[]>([]);
    const [columnDefs, setColumnDefs] = useState<any[]>([]);
    const [selectedRows, setSelectedRows] = useState<any[]>([]);
    const { useCustomFields, softDeleteByIds } = useStaff();
    const fields = useCustomFields();
    const [isEditModalVisible, setIsEditModalVisible] = useState(false);
    const [currentEditStaff, setCurrentEditStaff] = useState<any>(null);

    // 获取数据
    const { data: staffData } = api.staff.findMany.useQuery({
        where: {
            deletedAt: null
        },
        include: {
            fieldValues: {
                include: {
                    // 添加这两个关联字段
                    staff: { select: { id: true } },  // 关联员工ID
                    field: { select: { id: true } }   // 关联字段ID
                }
            },
            department: true
        }
    } as any);
    // console.log(staffData);
    const actionColumns = [{
        field: "action",
        width: 50,
        checkboxSelection: true,
        headerCheckboxSelection: true,
        pinned: 'left'
    }]
    // 新增编辑处理函数
    const handleEdit = useCallback(async () => {
        if (selectedRows.length === 0) return;
        if (selectedRows.length > 1) {
            message.error('只能选择一个员工进行编辑');
            return;
        }
        setCurrentEditStaff(selectedRows[0]);
        setIsEditModalVisible(true);
    }, [selectedRows]);
    console.log('选中行',currentEditStaff);
    // 处理编辑完成
    const handleEditComplete = useCallback(() => {
        setIsEditModalVisible(false);
        setCurrentEditStaff(null);
        // 刷新表格数据
        api.staff.findMany.useQuery();
    }, []);

    // 新增删除处理函数
    const handleDelete = useCallback(async () => {
        if (selectedRows.length === 0) return;
        console.log('待删除的选中行数据:', selectedRows); // 新增调试语句
        try {
            await softDeleteByIds.mutateAsync({
                ids: selectedRows?.map(row => {
                    console.log('当前行ID:', row.id); // 检查每个ID
                    return row.id
                })
            });
            message.success('删除成功');
        } catch (error) {
            message.error('删除失败');
            console.error('详细错误信息:', error); // 输出完整错误堆栈
        }
        // 重新获取数据或本地过滤已删除项
    }, [selectedRows]);

    // 缓存基础列定义
    const baseColumns = useMemo(() => [
        {
            field: 'showname',
            headerName: '姓名',
            filter: 'agSetColumnFilter',
            pinned: 'left'
        },
        {
            field: 'deptId',
            headerName: '所属部门',
            valueGetter: params => params.data.department?.name,
            filter: 'agSetColumnFilter'
        }
    ], []);

    // 缓存动态列定义
    const dynamicColumns = useMemo(() =>
        (fields.data || [] as any).map(field => ({
            field: field.name,
            headerName: field.label || field.name,
            filter: 'agSetColumnFilter',
            cellStyle: { whiteSpace: 'pre-line' },
            autoHeight: true,
            valueGetter: params => {
                // 获取原始值
                const rawValue = params.data.fieldValues?.find(
                    (fv: any) => fv.fieldId === field.id
                )?.value;

                // 根据字段类型格式化
                switch (field.type) {
                    case 'cascader':
                        return rawValue ? getAreaName(rawValue.split('/')) : '';

                    case 'date':
                        // 格式化日期（假设存储的是ISO字符串）
                        return rawValue ? new Date(rawValue).toLocaleDateString() : '';

                    case 'textarea':
                        // 换行处理 

                        return rawValue?.replace(/,/g, '\n');

                    default:
                        return rawValue;
                }
            }
        })),
        [fields.data]
    );
    // 合并列定义
    useEffect(() => {
        setColumnDefs([...actionColumns, ...baseColumns, ...dynamicColumns]);
    }, [baseColumns, dynamicColumns]);

    // 更新行数据
    useEffect(() => {
        staffData && setRowData(staffData);
    }, [staffData]);

    return (
        <>
            <div className="flex justify-between items-center mb-4">
                <div className="space-x-2">
                    <Button className="bg-red-500 hover:bg-red-600 border-red-500 text-white rounded-md px-4 py-2"
                        onClick={handleDelete}>批量删除</Button>
                    <Button className="bg-blue-500 hover:bg-blue-600 border-blue-500 text-white rounded-md px-4 py-2"
                        onClick={handleEdit}>编辑</Button>
                </div>
                <Button className="bg-gray-100 hover:bg-gray-200 border-gray-300 text-gray-700 rounded-md px-4 py-2"
                    onClick={() => {
                    }}>调试数据</Button>
            </div>

            <div className="bg-white rounded-lg shadow-md p-6 mb-4">
                <h1 className="text-2xl font-bold text-gray-800 mb-4">人员总览</h1>

                <div className="ag-theme-alpine w-full min-h-[480px] h-auto overflow-visible">
                    <AgGridReact
                        rowData={rowData}
                        columnDefs={columnDefs}
                        pagination={true}
                        paginationPageSize={10}
                        paginationPageSizeSelector={[10, 20, 50, 100]}
                        onSelectionChanged={e => setSelectedRows(e.api.getSelectedRows())}
                        rowSelection="multiple"
                        className="rounded border border-gray-200"
                        headerHeight={40}
                        rowHeight={40}
                        domLayout="autoHeight"
                    />
                </div>
            </div>
            
            {/* 编辑弹窗 */}
            <Modal
                title="编辑员工信息"
                open={isEditModalVisible}
                onCancel={() => setIsEditModalVisible(false)}
                footer={null}
                width={1000}
                destroyOnClose={true}
            >
                {currentEditStaff && (
                    <StaffInfoWrite 
                        staffId={currentEditStaff.id}
                        initialData={currentEditStaff}
                        fieldValues={currentEditStaff.fieldValues}
                        onComplete={handleEditComplete}
                        setIsEditModalVisible={setIsEditModalVisible}
                    />
                )}
            </Modal>
        </>
    );
}